@@ -1,9 +1,10 @@
 """ Main Application """
+import logging
 from datetime import datetime
 
 import click
 
-from nowcasting_forecast import N_GSP
+from nowcasting_forecast import N_GSP, __version__
 from nowcasting_forecast.batch import make_batches
 from nowcasting_forecast.database.connection import DatabaseConnection
 from nowcasting_forecast.database.fake import make_fake_forecasts, make_fake_national_forecast
@@ -11,6 +12,8 @@ from nowcasting_forecast.database.save import save
 from nowcasting_forecast.models.nwp_solar_simple import nwp_irradiance_simple_run_all_batches
 from nowcasting_forecast.utils import floor_30_minutes_dt
 
+logger = logging.getLogger(__name__)
+
 
 @click.command()
 @click.option(
@@ -34,6 +37,8 @@ def run(db_url: str, fake: bool = False):
     There is an option to make fake forecasts
     """
 
+    logger.info(f"Running forecast app ({__version__})")
+
     connection = DatabaseConnection(url=db_url)
     with connection.get_session() as session:
 
